@@ -8,12 +8,12 @@
     All generated figures can be accessed via the following link:
     https://github.com/Evolutionary-Intelligence/pypop/tree/main/docs/repeatability/bes
 
-    Since the current implementation is just a **highly simplified** version of the original BES algorithm
-    without noisy evaluations, its repeatability **cannot** be guaranteed.
+    Since the current Python implementation is only a *simplified* version of the original BES algorithm
+    without noisy function (fitness) evaluations, its repeatability **cannot** be guaranteed.
 
     However, we found that the current implementation could show *very similar* performance on the same
     benchmark functions (after removing its noise part). The resulting much less (>100x) number of function
-    evaluations to be needed may be well explained by the much easier fitness landscape (i.e., without noisiness).
+    evaluations needed may be well explained by the much easier fitness landscape (i.e., without noisiness).
 """
 import numpy as np
 import seaborn as sns
@@ -46,8 +46,8 @@ if __name__ == '__main__':
 
     problem = {'fitness_function': rosenbrock,
                'ndim_problem': 100,
-               'lower_boundary': -2 * np.ones((100,)),
-               'upper_boundary': 2 * np.ones((100,))}
+               'lower_boundary': -2*np.ones((100,)),
+               'upper_boundary': 2*np.ones((100,))}
     options = {'max_function_evaluations': 100*101,
                'seed_rng': 2,  # undefined in the original paper
                'x': np.random.default_rng(3).standard_normal(size=100),
